.. iptables-converter documentation master file, created by
   sphinx-quickstart on Sun Jul 21 16:47:22 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. toctree::
   :maxdepth: 1

   iptables-converter
   converter-tests
   sources

Contents:

.. toctree::
   :maxdepth: 2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

